ProofTranscriptStep

Enum ProofTranscriptStep 

pub enum ProofTranscriptStep<'a> {
    WitnessVar {
        var: Var,
    },
    SampleVar {
        var: Var,
    },
    HideVar {
        var: Var,
    },
    ObserveInternalVar {
        var: Var,
    },
    AddClause {
        clause: &'a [Lit],
    },
    Unsat,
    Model {
        assignment: &'a [Lit],
    },
    Assume {
        assumptions: &'a [Lit],
    },
    FailedAssumptions {
        failed_core: &'a [Lit],
    },
}
Step of a proof transcript.

The proof transcript contains the solver queries and results that correspond to a checked proof.

The transcript uses the same variable numbering as used for solver calls.

Variants



WitnessVar

Fields

var: Var


SampleVar

Fields

var: Var


HideVar

Fields

var: Var


ObserveInternalVar

Fields

var: Var


AddClause

Fields

clause: &'a [Lit]


Unsat



Model

Fields

assignment: &'a [Lit]


Assume

Fields

assumptions: &'a [Lit]


FailedAssumptions

Fields

failed_core: &'a [Lit]